# Creating Your Own Events

class Parent():

class Child():
    event: rio.EventHandler[DataClass] = None
    event: rio.EventHandler[int] = None
    event2: rio.EventHandler[[]] = None


def on_press():
    self.call_event_handler('onEventName', [arg1, arg2, ...]);
<!-- TODO -->